---
name: extended-prelude
description: Additional prelude functions, general purpose utilities. Including Int_conv, LChar_utils, etc. Copy paste the whole directory into your project and then import the modules you need.
---

# Extended prelude

This directory contains additional prelude functions, general purpose utilities. Including `Int_conv`, `LChar_utils`, etc.

They are not part of the standard IML prelude which is loaded by default.

The recommended way to use these utility modules / functions is to copy paste the whole directory into your project and then import the modules you need.
